@@ -5,6 +5,7 @@ from typing import List, Optional, Tuple, overload
 import tzlocal
 from nonebot import logger, require
 from sqlalchemy import select, update, delete
+from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.orm import selectinload
 from sqlalchemy.sql import Select
 
@@ -27,19 +28,19 @@ from nonebot_plugin_apscheduler import scheduler
 
 @scheduler.scheduled_job("cron", hour="*/2", id="delete_all_uncompleted_game")
 async def _delete_all_uncompleted_game():
-    session = data_source.session()
-
-    now = datetime.utcnow()
-    one_day_ago = now - timedelta(days=1)
-    stmt = (update(GameOrm)
-            .where(GameOrm.state != GameState.completed,
-                   GameOrm.create_time > one_day_ago,
-                   GameOrm.progress == None)
-            .values(accesible=False, delete_time=now, update_time=now)
-            .execution_options(synchronize_session=False))
-    result = await session.execute(stmt)
-    await session.commit()
-    logger.success(f"deleted {result.rowcount} outdated uncompleted game(s)")
+    async with AsyncSession(data_source.engine) as session:
+        now = datetime.utcnow()
+        one_day_ago = now - timedelta(days=1)
+        stmt = (update(GameOrm)
+                .where(GameOrm.state != GameState.completed,
+                       GameOrm.create_time > one_day_ago,
+                       GameOrm.progress == None,
+                       GameOrm.accessible)
+                .values(accesible=False, delete_time=now, update_time=now)
+                .execution_options(synchronize_session=False))
+        result = await session.execute(stmt)
+        await session.commit()
+        logger.success(f"deleted {result.rowcount} outdated uncompleted game(s)")
 
 
 async def new_game(promoter: UserOrm,
@@ -268,8 +269,10 @@ async def _handle_full_recorded_game(game: GameOrm):
     season = await session.get(SeasonOrm, game.season_id)
     if game.player_and_wind == PlayerAndWind.four_men_east:
         horse_point = season.config["east_game_horse_point"]
+        origin_point = season.config["east_game_origin_point"]
     elif game.player_and_wind == PlayerAndWind.four_men_south:
         horse_point = season.config["south_game_horse_point"]
+        origin_point = season.config["south_game_origin_point"]
     else:
         raise ValueError("invalid players and wind")
 
@@ -278,7 +281,6 @@ async def _handle_full_recorded_game(game: GameOrm):
     indexed_record.sort(key=lambda tup: tup[0].score, reverse=True)
 
     # 处理同分
-    # TODO：动态配置
     # 四人幸终
     if indexed_record[0][0].score == indexed_record[1][0].score == \
             indexed_record[2][0].score == indexed_record[3][0].score:
@@ -304,9 +306,8 @@ async def _handle_full_recorded_game(game: GameOrm):
         _divide_horse_point(indexed_record, horse_point, 2, 3)
 
     for i, (r, j) in enumerate(indexed_record):
-        # 30000返，1000点=1pt，切上
-        # TODO: 动态配置
-        r.point = horse_point[i] + ceil((r.score - 30000) / 1000)
+        # （点数-返点+马点）/1000，切上
+        r.point = horse_point[i] + ceil((r.score - origin_point) / 1000)
 
     await change_season_user_point_by_game(game)
 
@@ -385,8 +386,9 @@ async def delete_uncompleted_season_games(season: SeasonOrm):
     session = data_source.session()
     now = datetime.utcnow()
     stmt = (update(GameOrm)
-            .where(GameOrm.season == season, GameOrm.state != GameState.completed)
-            .values(accesible=False, delete_time=now, update_time=now))
+            .where(GameOrm.season == season, GameOrm.state != GameState.completed, GameOrm.accessible)
+            .values(accesible=False, delete_time=now, update_time=now)
+            .execution_options(synchronize_session=False))
     await session.execute(stmt)
     await session.commit()
 
